NAME
Catalyst::Helper::View::Wkhtmltopdf
VERSION
version v0.6.1
SYNOPSIS
script/create.pl view Wkhtmltopdf Wkhtmltopdf
DESCRIPTION
Helper for Wkhtmltopdf Views.
METHODS
mk_compclass
NAME
Catalyst::Helper::View::Wkhtmltopdf - Helper for Wkhtmltopdf Views
SEE ALSO
Catalyst::Manual, Catalyst::Test, Catalyst::Request, Catalyst::Response, Catalyst::Helper
AUTHOR
Michele Beltrame, mb@cattlegrid.info
LICENSE
This library is free software . You can redistribute it and/or modify it under the same terms as perl itself.
SOURCE
The development version is on github at https://github.com/robrwo/Catalyst-View-Wkhtmltopdf and may be cloned from https://github.com/robrwo/Catalyst-View-Wkhtmltopdf.git
SUPPORT
Please report any bugs or feature requests on the bugtracker website https://rt.cpan.org/Public/Dist/Display.html?Name=Catalyst-View-Wkhtmltopdf
When submitting a bug or request, please include a test-file or a patch to an existing test-file that illustrates the bug or desired feature.
AUTHOR
Michele Beltrame <mb@italpro.net>
COPYRIGHT AND LICENSE
This software is copyright (c) 2011-2018, 2026 by Michele Beltrame <mb@italpro.net>.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.
NAME
[% class %] - Catalyst Wkhtmltopdf View
SYNOPSIS
See "[% app %]"
DESCRIPTION
Catalyst Wkhtmltopdf View.
AUTHOR
[% author %]
LICENSE
This library is free software, you can redistribute it and/or modify it under the same terms as Perl itself.